/* Sistemas Integrados TECNISA
   Planejamento Alimentao Industrial

Nome: VERIFICA_RESTRICOES_CONTRATUAIS.SQL

Descrio:
Retorna a filial e os servicos que possuem restries contratuais referente ao cardapio

@C:\Web_605\Sql\End_Conv\Oracle\0322_PLAFUNO_VERIFICA_RESTRICOES_CONTRATUAIS.SQL

Criao:
28/12/2017 - Cristiane Faria

P_NRLISTA -> Lista de filiais/servios a serem verificados
P_VERRESTR -> DETERMINA SE A RESTRICAO SERA VERIFICADA INDEPENDENTE DO PARAMETRO NA PARAMPLANEJA
P_CDFILIAL -> FILIAL ESPECIFICADA
P_CDSERVFILI -> SERVICO ESPECIFICADO-> OU PASSA P_NRLISTA OU P_CDFILIAL E P_CDSERVFILI
Manutenes:
__/__/____ - _______ ___________
*/

DROP FUNCTION RESTR_CONTRATUAIS_CARD
/

DROP TYPE TABELA_RESTR_CONTRATUAIS_CARD
/

DROP TYPE LINHA_RESTR_CONTRATUAIS_CARD
/

CREATE TYPE LINHA_RESTR_CONTRATUAIS_CARD  AS OBJECT
   (CDFILIAL    VARCHAR2(04),
    CDSERVFILI  VARCHAR2(05)
    )
/

CREATE TYPE TABELA_RESTR_CONTRATUAIS_CARD AS TABLE OF LINHA_RESTR_CONTRATUAIS_CARD
/

create or replace FUNCTION RESTR_CONTRATUAIS_CARD(
   P_CDFILIAL     IN VARCHAR2,
   P_CDSERVFILI   IN VARCHAR2,
   P_NRLISTA      IN VARCHAR2,
   P_DTINICIAL    IN DATE,
   P_DTFINAL      IN DATE,
   P_VERRESTR     VARCHAR2 DEFAULT 'S') RETURN TABELA_RESTR_CONTRATUAIS_CARD PIPELINED
IS
   V_OUT_RECORD LINHA_RESTR_CONTRATUAIS_CARD := LINHA_RESTR_CONTRATUAIS_CARD (NULL, NULL);
   V_RESTRICAO NUMBER;
   V_IDRESTRAPROVCARD VARCHAR2(01);
   /*Frequncia de Pratos no Ms*/
   CURSOR C_FREQPRATMES(V_CDFILIAL VARCHAR2,
                        V_CDSERVFILI VARCHAR2,
                        P_DTINICIAL DATE,
                        P_DTFINAL DATE)
   IS
      SELECT SUM(RESTRICAO) AS RESTRICAO
        FROM (
            SELECT FP.CDFILIAL,
                   FP.CDSERVFILI,
                   FP.CDPRATO,
                   FP.NRMAXIFREPRA,
                   PR.NMPRATO,
                   LPAD(TO_CHAR(CA.DTCARDAPIO,'IW'), 2, '0') AS NRSEMANA,
                   COUNT(*) AS RESTRICAO
              FROM FREQPRAT FP,
                   COMPCARD CC,
                   CARDADIA CA,
                   CNFCAMES CM,
                   PRATO PR
             WHERE
               (FP.CDFILIAL     = V_CDFILIAL)              AND
               (FP.CDSERVFILI   = V_CDSERVFILI)            AND
               (CA.CDFILIAL     = V_CDFILIAL)              AND
               (CA.CDSERVFILI   = V_CDSERVFILI)            AND
               (CA.DTCARDAPIO BETWEEN P_DTINICIAL AND P_DTFINAL)    AND
               (CC.CDFILIAL     = V_CDFILIAL)                       AND
               (CC.NRCARDAPIO   = CA.NRCARDAPIO)                    AND
               (INSTR(CC.CDPRATO, FP.CDPRATO) = 1)                  AND
               (CM.CDFILIAL     = V_CDFILIAL)                       AND
               (CM.CDSERVFILI   = V_CDSERVFILI)                     AND
               (CM.DTREFECNFMES = CA.DTMESCARD)                     AND
               (CM.NRSEQCNFMES  = CC.NRSEQPRATCAR)                  AND
               (CM.IDOPCCNFMES  = 'N')                              AND
               (PR.CDFILAUXPRAT = FP.CDFILAUXPRAT)                  AND
               (PR.CDPRATO      = FP.CDPRATO)
             GROUP BY
                FP.CDFILIAL,
                FP.CDSERVFILI,
                FP.CDPRATO,
                FP.NRMAXIFREPRA,
                PR.NMPRATO,
                TO_CHAR(CA.DTCARDAPIO,'IW')
            HAVING
               (COUNT(*) > FP.NRMAXIFREPRA)
         );
   RECORD_FREQPRATMES C_FREQPRATMES%ROWTYPE;
   /*Frequncia de Pratos no Ms, verificando o minimo e o maximo por prato*/
   CURSOR C_FREQPRATMESMIN(V_CDFILIAL VARCHAR2,
                           V_CDSERVFILI VARCHAR2,
                           P_DTINICIAL DATE,
                           P_DTFINAL DATE)
   IS
      SELECT SUM(RESTRICAO) AS RESTRICAO
        FROM (
            SELECT FP.CDFILIAL,
                   FP.CDSERVFILI,
                   FP.CDPRATO,
                   FP.NRMINIFREPRA,
                   FP.NRMAXMESFPRA,
                   PR.NMPRATO,
                   CA.DTMESCARD,
                   COUNT(*) AS RESTRICAO
            FROM FREQPRAT FP,
                 COMPCARD CC,
                 CARDADIA CA,
                 CNFCAMES CM,
                 PRATO PR
            WHERE
                (FP.CDFILIAL     = V_CDFILIAL)               AND
                (FP.CDSERVFILI   = V_CDSERVFILI)             AND
                (CA.CDFILIAL     = V_CDFILIAL)               AND
                (CA.CDSERVFILI   = V_CDSERVFILI)             AND
                (CA.DTCARDAPIO BETWEEN P_DTINICIAL AND P_DTFINAL)     AND
                (CC.CDFILIAL     = V_CDFILIAL)               AND
                (CC.NRCARDAPIO   = CA.NRCARDAPIO)            AND
                (INSTR(CC.CDPRATO, FP.CDPRATO) = 1)          AND
                (CM.CDFILIAL     = V_CDFILIAL)               AND
                (CM.CDSERVFILI   = V_CDSERVFILI)             AND
                (CM.DTREFECNFMES = CA.DTMESCARD)             AND
                (CM.NRSEQCNFMES  = CC.NRSEQPRATCAR)          AND
                (CM.IDOPCCNFMES  = 'N')                      AND
                (PR.CDFILAUXPRAT = FP.CDFILAUXPRAT)          AND
                (PR.CDPRATO      = FP.CDPRATO)
            GROUP BY
                  FP.CDFILIAL,
                  FP.CDSERVFILI,
                  FP.CDPRATO,
                  FP.NRMINIFREPRA,
                  FP.NRMAXMESFPRA,
                  PR.NMPRATO,
                  CA.DTMESCARD
            HAVING (COUNT(*) < FP.NRMINIFREPRA) OR (COUNT(*) > FP.NRMAXMESFPRA)
            UNION ALL
            SELECT FP.CDFILIAL,
                   FP.CDSERVFILI,
                   FP.CDPRATO,
                   FP.NRMINIFREPRA,
                   FP.NRMAXMESFPRA,
                   PR.NMPRATO,
                   TO_DATE(P_DTINICIAL,'DD/MM/YYYY') AS DTMESCARD,
                   COUNT(*) AS RESTRICAO
            FROM
               FREQPRAT FP,
               PRATO PR
           WHERE
               (FP.CDFILIAL     = V_CDFILIAL)                           AND
               (FP.CDSERVFILI   = V_CDSERVFILI)                         AND
               (PR.CDFILAUXPRAT = FP.CDFILAUXPRAT)                      AND
               (PR.CDPRATO      = FP.CDPRATO)                           AND
               NOT EXISTS (SELECT CC.CDPRATO
                             FROM COMPCARD CC,
                                  CARDADIA CA,
                                  CNFCAMES CM
                            WHERE (CA.CDFILIAL     = FP.CDFILIAL)     AND
                                  (CA.CDSERVFILI   = FP.CDSERVFILI)   AND
                                  (CA.DTCARDAPIO BETWEEN P_DTINICIAL AND P_DTFINAL) AND
                                  (CC.CDFILIAL     = FP.CDFILIAL)     AND
                                  (CC.NRCARDAPIO   = CA.NRCARDAPIO)   AND
                                  (INSTR(CC.CDPRATO, FP.CDPRATO) = 1) AND
                                  (CM.CDFILIAL     = FP.CDFILIAL)     AND
                                  (CM.CDSERVFILI   = FP.CDSERVFILI)   AND
                                  (CM.DTREFECNFMES = CA.DTMESCARD)    AND
                                  (CM.NRSEQCNFMES  = CC.NRSEQPRATCAR) AND
                                  (CM.IDOPCCNFMES  = 'N'))
           GROUP BY
                 FP.CDFILIAL,
                 FP.CDSERVFILI,
                 FP.CDPRATO,
                 FP.NRMINIFREPRA,
                 FP.NRMAXMESFPRA,
                 PR.NMPRATO,
                 TO_DATE(P_DTINICIAL,'DD/MM/YYYY')
           );
   RECORD_FREQPRATMESMIN C_FREQPRATMESMIN%ROWTYPE;
   /*Frequncia de Opes no Ms*/
   CURSOR C_FREQOPCASEM(V_CDFILIAL VARCHAR2,
                        V_CDSERVFILI VARCHAR2,
                        P_DTINICIAL DATE,
                        P_DTFINAL DATE)
   IS
      SELECT SUM(RESTRICAO) AS RESTRICAO
        FROM (
            SELECT FO.CDFILIAL,
                   FO.CDSERVFILI,
                   FO.CDPRATO,
                   FO.NRMAXIFREOPC,
                   PR.NMPRATO,
                   LPAD(TO_CHAR(CA.DTCARDAPIO,'IW'), 2, '0') AS NRSEMANA,
                   COUNT(*) AS RESTRICAO
              FROM FREQOPCA FO,
                   COMPCARD CC,
                   CARDADIA CA,
                   CNFCAMES CM,
                   PRATO PR
            WHERE
               (FO.CDFILIAL     = V_CDFILIAL)            AND
               (FO.CDSERVFILI   = V_CDSERVFILI)          AND
               (CA.CDFILIAL     = V_CDFILIAL)            AND
               (CA.CDSERVFILI   = V_CDSERVFILI)          AND
               (CA.DTCARDAPIO BETWEEN P_DTINICIAL AND P_DTFINAL)  AND
               (CC.CDFILIAL     = V_CDFILIAL)            AND
               (CC.NRCARDAPIO   = CA.NRCARDAPIO)         AND
               (INSTR(CC.CDPRATO, FO.CDPRATO) = 1)       AND
               (CM.CDFILIAL     = V_CDFILIAL)            AND
               (CM.CDSERVFILI   = V_CDSERVFILI)          AND
               (CM.DTREFECNFMES = CA.DTMESCARD)          AND
               (CM.NRSEQCNFMES  = CC.NRSEQPRATCAR)       AND
               (CM.IDOPCCNFMES  = 'S')                   AND
               (PR.CDFILAUXPRAT = FO.CDFILAUXPRAT)       AND
               (PR.CDPRATO      = FO.CDPRATO)
            GROUP BY
               FO.CDFILIAL,
               FO.CDSERVFILI,
               FO.CDPRATO,
               FO.NRMAXIFREOPC,
               PR.NMPRATO,
               TO_CHAR(CA.DTCARDAPIO,'IW')
            HAVING
               (COUNT(*) > FO.NRMAXIFREOPC)
            );
   RECORD_FREQOPCASEM C_FREQOPCASEM%ROWTYPE;
   /*Frequncia de Opes no Ms, verificando o minimo e o maximo*/
   CURSOR C_FREQOPCASEMMIN(V_CDFILIAL VARCHAR2,
                        V_CDSERVFILI VARCHAR2,
                        P_DTINICIAL DATE,
                        P_DTFINAL DATE)
   IS
      SELECT SUM(RESTRICAO) AS RESTRICAO
        FROM (
            SELECT FO.CDFILIAL,
                   FO.CDSERVFILI,
                   FO.CDPRATO,
                   FO.NRMINIFREOPC,
                   FO.NRMAXMESFOPC,
                   PR.NMPRATO,
                   CA.DTMESCARD,
                   COUNT(*) AS RESTRICAO
            FROM
               FREQOPCA FO,
               COMPCARD CC,
               CARDADIA CA,
               CNFCAMES CM,
               PRATO PR
            WHERE
               (FO.CDFILIAL     = V_CDFILIAL)              AND
               (FO.CDSERVFILI   = V_CDSERVFILI)            AND
               (CA.CDFILIAL     = V_CDFILIAL)              AND
               (CA.CDSERVFILI   = V_CDSERVFILI)            AND
               (CA.DTCARDAPIO BETWEEN P_DTINICIAL AND P_DTFINAL)    AND
               (CC.CDFILIAL     = V_CDFILIAL)              AND
               (CC.NRCARDAPIO   = CA.NRCARDAPIO)           AND
               (INSTR(CC.CDPRATO, FO.CDPRATO) = 1)         AND
               (CM.CDFILIAL     = V_CDFILIAL)              AND
               (CM.CDSERVFILI   = V_CDSERVFILI)            AND
               (CM.DTREFECNFMES = CA.DTMESCARD)            AND
               (CM.NRSEQCNFMES  = CC.NRSEQPRATCAR)         AND
               (CM.IDOPCCNFMES  = 'S')                     AND
               (PR.CDFILAUXPRAT = FO.CDFILAUXPRAT)         AND
               (PR.CDPRATO      = FO.CDPRATO)
            GROUP BY
               FO.CDFILIAL,
               FO.CDSERVFILI,
               FO.CDPRATO,
               FO.NRMINIFREOPC,
               FO.NRMAXMESFOPC,
               PR.NMPRATO,
               CA.DTMESCARD
            HAVING
               (COUNT(*) < FO.NRMINIFREOPC) OR (COUNT(*) > FO.NRMAXMESFOPC)
            );
   RECORD_FREQOPCASEMMIN C_FREQOPCASEMMIN%ROWTYPE;
   /*Restrio de Pratos no Ms*/
   CURSOR C_RESTPRATMES(V_CDFILIAL VARCHAR2,
                        V_CDSERVFILI VARCHAR2,
                        P_DTINICIAL DATE,
                        P_DTFINAL DATE)
   IS
      SELECT COUNT(*) AS RESTRICAO
      FROM RESTPRAT RP,
           COMPCARD CC,
           CARDADIA CA,
           CNFCAMES CM,
           PRATO PR
      WHERE
         (RP.CDFILIAL     = V_CDFILIAL)            AND
         (RP.CDSERVFILI   = V_CDSERVFILI)          AND
         (CA.CDFILIAL     = V_CDFILIAL)            AND
         (CA.CDSERVFILI   = V_CDSERVFILI)          AND
         (CA.DTCARDAPIO BETWEEN P_DTINICIAL AND P_DTFINAL)  AND
         (CC.CDFILIAL     = V_CDFILIAL)                     AND
         (CC.NRCARDAPIO   = CA.NRCARDAPIO)                  AND
         (INSTR(CC.CDPRATO, RP.CDPRATO) = 1)                AND
         (CM.CDFILIAL     = V_CDFILIAL)                     AND
         (CM.CDSERVFILI   = V_CDSERVFILI)                   AND
         (CM.DTREFECNFMES = CA.DTMESCARD)                   AND
         (CM.NRSEQCNFMES  = CC.NRSEQPRATCAR)                AND
         (CM.IDOPCCNFMES  = 'N')                            AND
         (PR.CDFILAUXPRAT = RP.CDFILAUXPRAT)                AND
         (PR.CDPRATO      = RP.CDPRATO);       
   RECORD_RESTPRATMES C_RESTPRATMES%ROWTYPE;
   /*Restrio de Opces no Ms*/
   CURSOR C_RESTOPCA(V_CDFILIAL VARCHAR2,
                     V_CDSERVFILI VARCHAR2,
                     P_DTINICIAL DATE,
                     P_DTFINAL DATE)
   IS
      SELECT COUNT(*) AS RESTRICAO
        FROM RESTOPCA RO,
             COMPCARD CC,
             CARDADIA CA,
             CNFCAMES CM,
             PRATO PR
       WHERE
         (RO.CDFILIAL     = V_CDFILIAL)               AND
         (RO.CDSERVFILI   = V_CDSERVFILI)             AND
         (CA.CDFILIAL     = V_CDFILIAL)               AND
         (CA.CDSERVFILI   = V_CDSERVFILI)             AND
         (CA.DTCARDAPIO BETWEEN P_DTINICIAL AND P_DTFINAL)   AND
         (CC.CDFILIAL     = V_CDFILIAL)                      AND
         (CC.NRCARDAPIO   = CA.NRCARDAPIO)                   AND
         (INSTR(CC.CDPRATO, RO.CDPRATO) = 1)                 AND
         (CM.CDFILIAL     = V_CDFILIAL)                      AND
         (CM.CDSERVFILI   = V_CDSERVFILI)                    AND
         (CM.DTREFECNFMES = CA.DTMESCARD)                    AND
         (CM.NRSEQCNFMES  = CC.NRSEQPRATCAR)                 AND
         (CM.IDOPCCNFMES  = 'S')                             AND
         (PR.CDFILAUXPRAT = RO.CDFILAUXPRAT)                 AND
         (PR.CDPRATO      = RO.CDPRATO);
   RECORD_RESTOPCA C_RESTOPCA%ROWTYPE;
   /*Utilizao de Pratos na Semana*/
   CURSOR C_UTILPRAT(V_CDFILIAL VARCHAR2,
                     V_CDSERVFILI VARCHAR2,
                     P_DTINICIAL DATE,
                     P_DTFINAL DATE)
   IS
      SELECT COUNT(*) AS RESTRICAO
      FROM UTILPRATSEM UP,
           COMPCARD CC,
           CARDADIA CA,
           PRATO PR
      WHERE
         (UP.CDFILIAL     = V_CDFILIAL)               AND
         (UP.CDSERVFILI   = V_CDSERVFILI)    AND
         (CA.CDFILIAL     = V_CDFILIAL)      AND
         (CA.CDSERVFILI   = V_CDSERVFILI)    AND
         (CA.DTCARDAPIO BETWEEN P_DTINICIAL AND P_DTFINAL) AND
         ( ((TO_CHAR(CA.DTCARDAPIO, 'D') = '1') AND
           (UP.IDUTPRATDOM = 'N')) OR
           ((TO_CHAR(CA.DTCARDAPIO, 'D') = '2') AND
           (UP.IDUTPRATSEG = 'N')) OR
           ((TO_CHAR(CA.DTCARDAPIO, 'D') = '3') AND
           (UP.IDUTPRATTER = 'N')) OR
           ((TO_CHAR(CA.DTCARDAPIO, 'D') = '4') AND
           (UP.IDUTPRATQUA = 'N')) OR
           ((TO_CHAR(CA.DTCARDAPIO, 'D') = '5') AND
           (UP.IDUTPRATQUI = 'N')) OR
           ((TO_CHAR(CA.DTCARDAPIO, 'D') = '6') AND
           (UP.IDUTPRATSEX = 'N')) OR
           ((TO_CHAR(CA.DTCARDAPIO, 'D') = '7') AND
           (UP.IDUTPRATSAB = 'N')) )                           AND
         (CC.CDFILIAL     = V_CDFILIAL)                        AND
         (CC.NRCARDAPIO   = CA.NRCARDAPIO)                     AND
         (INSTR(CC.CDPRATO, UP.CDPRATO) = 1)                   AND
         (PR.CDFILAUXPRAT = UP.CDFILAUXPRAT)                   AND
         (PR.CDPRATO      = UP.CDPRATO);
   RECORD_UTILPRAT C_UTILPRAT%ROWTYPE;
   /*Limite de Nutrientes por Servio*/
   CURSOR C_LIMNUTRI(V_CDFILIAL VARCHAR2,
                     V_CDSERVFILI VARCHAR2,
                     P_DTINICIAL DATE,
                     P_DTFINAL DATE)
   IS
      SELECT COUNT(*) AS RESTRICAO
      FROM
         LIMNUTRI LN,
         NUTRIENTE NU,
         (SELECT
            CDFILIAL,
            CDSERVFILI,
            DTCARDAPIO,
            DTMESCARD,
            CDNUTRIENTE,
            SUM(QTNUTRIENTE) AS QTNUTRIENTE
          FROM
             (SELECT
                 CA.CDFILIAL,
                 CA.CDSERVFILI,
                 CA.DTCARDAPIO,
                 CA.DTMESCARD,
                 CC.CDPRATO,
                 RS.CDPRODUTO,
                 NP.CDNUTRIENTE,
                 NP.QTNUTRPROD * 10 * PR.VRPESOUNID *
                 RS.QTUNIDESTSE AS QTNUTRIENTE
              FROM
                 NUTRPROD NP,
                 PRODUTO PR,
                 RECESERV RS,
                 COMPCARD CC,
                 CARDADIA CA
              WHERE
                 (CA.CDFILIAL     = V_CDFILIAL)           AND
                 (CA.CDSERVFILI   = V_CDSERVFILI)         AND
                 (CA.DTCARDAPIO BETWEEN P_DTINICIAL AND P_DTFINAL) AND
                 (CC.CDFILIAL     = V_CDFILIAL) AND
                 (CC.NRCARDAPIO   = CA.NRCARDAPIO)       AND
                 (CC.VRPECONSCARD = 100)                 AND
                 (RS.CDFILIAL     = V_CDFILIAL) AND
                 (RS.CDSERVFILI   = V_CDSERVFILI) AND
                 (RS.CDFILAUXPRAT = CC.CDFILAUXPRAT)     AND
                 (RS.CDPRATO      = CC.CDPRATO)          AND
                 (NP.CDPRODUTO    = RS.CDPRODUTO)        AND
                 (PR.CDPRODUTO    = RS.CDPRODUTO)
              UNION ALL
              SELECT
                 CA.CDFILIAL,
                 CA.CDSERVFILI,
                 CA.DTCARDAPIO,
                 CA.DTMESCARD,
                 CC.CDPRATO,
                 RF.CDPRODUTO,
                 NP.CDNUTRIENTE,
                 NP.QTNUTRPROD * 10 * PR.VRPESOUNID *
                 RF.QTUNIDESTLO AS QTNUTRIENTE
              FROM
                 NUTRPROD NP,
                 PRODUTO PR,
                 RECEFILI RF,
                 COMPCARD CC,
                 CARDADIA CA
              WHERE
                 (CA.CDFILIAL     = V_CDFILIAL)                     AND
                 (CA.CDSERVFILI   = V_CDSERVFILI)                   AND
                 (CA.DTCARDAPIO BETWEEN P_DTINICIAL AND P_DTFINAL)           AND
                 (CC.CDFILIAL     = V_CDFILIAL)                     AND
                 (CC.NRCARDAPIO   = CA.NRCARDAPIO)                           AND
                 (CC.VRPECONSCARD = 100)                                     AND
                 (RF.CDFILIAL     = V_CDFILIAL)                     AND
                 (RF.CDFILAUXPRAT = CC.CDFILAUXPRAT)                         AND
                 (RF.CDPRATO      = CC.CDPRATO)                              AND
                 (NP.CDPRODUTO    = RF.CDPRODUTO)                            AND
                 (PR.CDPRODUTO    = RF.CDPRODUTO)                            AND
                 NOT EXISTS (SELECT CDPRATO
                             FROM RECESERV
                             WHERE
                                (CDFILAUXPRAT = CC.CDFILAUXPRAT) AND
                                (CDPRATO      = CC.CDPRATO)      AND
                                (CDFILIAL     = V_CDFILIAL) AND
                                (CDSERVFILI   = V_CDSERVFILI)
                             )
              UNION ALL
              SELECT
                 CA.CDFILIAL,
                 CA.CDSERVFILI,
                 CA.DTCARDAPIO,
                 CA.DTMESCARD,
                 CC.CDPRATO,
                 RP.CDPRODUTO,
                 NP.CDNUTRIENTE,
                 NP.QTNUTRPROD * 10 * PR.VRPESOUNID *
                 RP.QTUNIDESTPR AS QTNUTRIENTE
              FROM
                 NUTRPROD NP,
                 PRODUTO PR,
                 RECEPADR RP,
                 COMPCARD CC,
                 CARDADIA CA
              WHERE
                 (CA.CDFILIAL     = V_CDFILIAL)                     AND
                 (CA.CDSERVFILI   = V_CDSERVFILI)                   AND
                 (CA.DTCARDAPIO BETWEEN P_DTINICIAL AND P_DTFINAL)           AND
                 (CC.CDFILIAL     = V_CDFILIAL)                     AND
                 (CC.NRCARDAPIO   = CA.NRCARDAPIO)                           AND
                 (CC.VRPECONSCARD = 100)                                     AND
                 (RP.CDFILAUXPRAT = 'P')                                     AND
                 (RP.CDPRATO      = CC.CDPRATO)                              AND
                 (NP.CDPRODUTO    = RP.CDPRODUTO)                            AND
                 (PR.CDPRODUTO    = RP.CDPRODUTO)                            AND
                 NOT EXISTS (SELECT CDPRATO
                             FROM RECEFILI
                             WHERE
                                (CDFILAUXPRAT = CC.CDFILAUXPRAT) AND
                                (CDPRATO      = CC.CDPRATO)      AND
                                (CDFILIAL     = V_CDFILIAL)
                             )
                 AND
                 NOT EXISTS (SELECT CDPRATO
                             FROM RECESERV
                             WHERE
                                (CDFILAUXPRAT = CC.CDFILAUXPRAT) AND
                                (CDPRATO      = CC.CDPRATO)      AND
                                (CDFILIAL     = V_CDFILIAL) AND
                                (CDSERVFILI   = V_CDSERVFILI)
                             )
              )
          GROUP BY
             CDFILIAL,
             CDSERVFILI,
             DTCARDAPIO,
             DTMESCARD,
             CDNUTRIENTE
          ) NC
      WHERE
         (LN.CDFILIAL    = V_CDFILIAL)          AND
         (LN.CDSERVFILI  = V_CDSERVFILI)        AND
         ((NC.QTNUTRIENTE < LN.QTMINLIMNUTR) OR
          (NC.QTNUTRIENTE > LN.QTMAXLIMNUTR))    AND
         (NC.CDNUTRIENTE = LN.CDNUTRIENTE)       AND
         (NU.CDNUTRIENTE = LN.CDNUTRIENTE);
   RECORD_LIMNUTRI C_LIMNUTRI%ROWTYPE;
   /*Limite de Per Capita por Prato*/
   CURSOR C_LIMPERPRAT(V_CDFILIAL VARCHAR2,
                     V_CDSERVFILI VARCHAR2,
                     P_DTINICIAL DATE,
                     P_DTFINAL DATE)
   IS
      SELECT COUNT(*) AS RESTRICAO
      FROM LIMPEPRA LP,
           PRATO PT,
           PRODUTO PR,
      (SELECT
          CA.CDFILIAL,
          CA.CDSERVFILI,
          CA.DTCARDAPIO,
          CA.DTMESCARD,
          CC.NRSEQPRATCAR,
          CC.CDTIPOPRAT,
          CC.CDFILAUXPRAT,
          CC.CDPRATO,
          CM.IDOPCCNFMES,
          RS.CDPRODUTO,
          RS.QTUNIDESTSE AS QTPRODUTO
       FROM
          CARDADIA CA,
          COMPCARD CC,
          CNFCAMES CM,
          RECESERV RS,
          PRODUTO PR
       WHERE
          (CA.CDFILIAL     = V_CDFILIAL)             AND
          (CA.CDSERVFILI   = V_CDSERVFILI)           AND
          (CA.DTCARDAPIO BETWEEN P_DTINICIAL AND P_DTFINAL)   AND
          (CC.CDFILIAL     = V_CDFILIAL)                      AND
          (CC.NRCARDAPIO   = CA.NRCARDAPIO)                   AND
          (CM.CDFILIAL     = V_CDFILIAL)                      AND
          (CM.CDSERVFILI   = V_CDSERVFILI)                    AND
          (CM.DTREFECNFMES = CA.DTMESCARD)                    AND
          (CM.NRSEQCNFMES  = CC.NRSEQPRATCAR)                 AND
          (RS.CDFILIAL     = V_CDFILIAL)                      AND
          (RS.CDSERVFILI   = V_CDSERVFILI)                    AND
          (RS.CDFILAUXPRAT = CC.CDFILAUXPRAT)                 AND
          (RS.CDPRATO      = CC.CDPRATO)                      AND
          (PR.CDPRODUTO    = RS.CDPRODUTO)
       UNION ALL
       SELECT
          CA.CDFILIAL,
          CA.CDSERVFILI,
          CA.DTCARDAPIO,
          CA.DTMESCARD,
          CC.NRSEQPRATCAR,
          CC.CDTIPOPRAT,
          CC.CDFILAUXPRAT,
          CC.CDPRATO,
          CM.IDOPCCNFMES,
          RF.CDPRODUTO,
          RF.QTUNIDESTLO AS QTPRODUTO
       FROM
          CARDADIA CA,
          COMPCARD CC,
          CNFCAMES CM,
          RECEFILI RF,
          PRODUTO PR
       WHERE
          (CA.CDFILIAL     = V_CDFILIAL)             AND
          (CA.CDSERVFILI   = V_CDSERVFILI)           AND
          (CA.DTCARDAPIO BETWEEN P_DTINICIAL AND P_DTFINAL)   AND
          (CC.CDFILIAL     = V_CDFILIAL)                      AND
          (CC.NRCARDAPIO   = CA.NRCARDAPIO)                   AND
          (CM.CDFILIAL     = V_CDFILIAL)                      AND
          (CM.CDSERVFILI   = V_CDSERVFILI)                    AND
          (CM.DTREFECNFMES = CA.DTMESCARD)                    AND
          (CM.NRSEQCNFMES  = CC.NRSEQPRATCAR)                 AND
          (RF.CDFILIAL     = V_CDFILIAL)                      AND
          (RF.CDFILAUXPRAT = CC.CDFILAUXPRAT)                 AND
          (RF.CDPRATO      = CC.CDPRATO)                      AND
          (PR.CDPRODUTO    = RF.CDPRODUTO)                    AND
          NOT EXISTS (SELECT
                         CDPRATO
                      FROM
                         RECESERV
                      WHERE
                         (CDFILAUXPRAT = CC.CDFILAUXPRAT) AND
                         (CDPRATO      = CC.CDPRATO)      AND
                         (CDFILIAL     = V_CDFILIAL)      AND
                         (CDSERVFILI   = V_CDSERVFILI)
                      )
       UNION ALL
       SELECT
          CA.CDFILIAL,
          CA.CDSERVFILI,
          CA.DTCARDAPIO,
          CA.DTMESCARD,
          CC.NRSEQPRATCAR,
          CC.CDTIPOPRAT,
          CC.CDFILAUXPRAT,
          CC.CDPRATO,
          CM.IDOPCCNFMES,
          RP.CDPRODUTO,
          RP.QTUNIDESTPR AS QTPRODUTO
       FROM
          CARDADIA CA,
          COMPCARD CC,
          CNFCAMES CM,
          RECEPADR RP,
          PRODUTO PR
       WHERE
          (CA.CDFILIAL     = V_CDFILIAL)             AND
          (CA.CDSERVFILI   = V_CDSERVFILI)           AND
          (CA.DTCARDAPIO BETWEEN P_DTINICIAL AND P_DTFINAL)   AND
          (CC.CDFILIAL     = V_CDFILIAL)                      AND
          (CC.NRCARDAPIO   = CA.NRCARDAPIO)                   AND
          (CM.CDFILIAL     = V_CDFILIAL)                      AND
          (CM.CDSERVFILI   = V_CDSERVFILI)                    AND
          (CM.DTREFECNFMES = CA.DTMESCARD)                    AND
          (CM.NRSEQCNFMES  = CC.NRSEQPRATCAR)                 AND
          (RP.CDFILAUXPRAT = 'P')                             AND
          (RP.CDPRATO      = CC.CDPRATO)                      AND
          (PR.CDPRODUTO    = RP.CDPRODUTO)                    AND
          NOT EXISTS (SELECT
                         CDPRATO
                      FROM
                         RECEFILI
                      WHERE
                         (CDFILAUXPRAT = CC.CDFILAUXPRAT) AND
                         (CDPRATO      = CC.CDPRATO)      AND
                         (CDFILIAL     = V_CDFILIAL)
                      )                                   AND
          NOT EXISTS (SELECT
                         CDPRATO
                      FROM
                         RECESERV
                      WHERE
                         (CDFILAUXPRAT = CC.CDFILAUXPRAT) AND
                         (CDPRATO      = CC.CDPRATO)      AND
                         (CDFILIAL     = V_CDFILIAL)      AND
                         (CDSERVFILI   = V_CDSERVFILI)
                      )
      ) PC
   WHERE
      (LP.CDFILIAL     = V_CDFILIAL)                                             AND
      (LP.CDSERVFILI   = V_CDSERVFILI)                                           AND
      (INSTR(PC.CDPRODUTO, LP.CDPRODUTO) = 1)                                    AND
      (INSTR(PC.CDPRATO, LP.CDPRATO) = 1)                                        AND
      ((PC.QTPRODUTO < LP.QTMINLIMPRAT) OR
       (PC.QTPRODUTO > LP.QTMAXLIMPRAT))                                         AND
      (PT.CDFILAUXPRAT = LP.CDFILAUXPRAT)                                        AND
      (PT.CDPRATO      = LP.CDPRATO)                                             AND
      (PR.CDPRODUTO    = LP.CDPRODUTO);
   RECORD_LIMPERPRAT C_LIMPERPRAT%ROWTYPE;
   /*Limite de Per Capita por Servio*/
   CURSOR C_LIMPERSER(V_CDFILIAL VARCHAR2,
                     V_CDSERVFILI VARCHAR2,
                     P_DTINICIAL DATE,
                     P_DTFINAL DATE)
   IS
      SELECT COUNT(*) AS RESTRICAO
        FROM LIMPESER LP,
             PRODUTO PR,
         (SELECT
             CA.CDFILIAL,
             CA.CDSERVFILI,
             CA.DTCARDAPIO,
             CA.DTMESCARD,
             CC.NRSEQPRATCAR,
             CC.CDTIPOPRAT,
             CC.CDFILAUXPRAT,
             CC.CDPRATO,
             CM.IDOPCCNFMES,
             RS.CDPRODUTO,
             RS.QTUNIDESTSE AS QTPRODUTO
          FROM
             CARDADIA CA,
             COMPCARD CC,
             CNFCAMES CM,
             RECESERV RS,
             PRODUTO PR
          WHERE
             (CA.CDFILIAL     = V_CDFILIAL)             AND
             (CA.CDSERVFILI   = V_CDSERVFILI)           AND
             (CA.DTCARDAPIO BETWEEN P_DTINICIAL AND P_DTFINAL)   AND
             (CC.CDFILIAL     = V_CDFILIAL)                      AND
             (CC.NRCARDAPIO   = CA.NRCARDAPIO)                   AND
             (CM.CDFILIAL     = V_CDFILIAL)                      AND
             (CM.CDSERVFILI   = V_CDSERVFILI)                    AND
             (CM.DTREFECNFMES = CA.DTMESCARD)                    AND
             (CM.NRSEQCNFMES  = CC.NRSEQPRATCAR)                 AND
             (RS.CDFILIAL     = V_CDFILIAL)                      AND
             (RS.CDSERVFILI   = V_CDSERVFILI)                    AND
             (RS.CDFILAUXPRAT = CC.CDFILAUXPRAT)                 AND
             (RS.CDPRATO      = CC.CDPRATO)                      AND
             (PR.CDPRODUTO    = RS.CDPRODUTO)
          UNION ALL
          SELECT
             CA.CDFILIAL,
             CA.CDSERVFILI,
             CA.DTCARDAPIO,
             CA.DTMESCARD,
             CC.NRSEQPRATCAR,
             CC.CDTIPOPRAT,
             CC.CDFILAUXPRAT,
             CC.CDPRATO,
             CM.IDOPCCNFMES,
             RF.CDPRODUTO,
             RF.QTUNIDESTLO AS QTPRODUTO
          FROM
             CARDADIA CA,
             COMPCARD CC,
             CNFCAMES CM,
             RECEFILI RF,
             PRODUTO PR
          WHERE
             (CA.CDFILIAL     = V_CDFILIAL)             AND
             (CA.CDSERVFILI   = V_CDSERVFILI)           AND
             (CA.DTCARDAPIO BETWEEN P_DTINICIAL AND P_DTFINAL)   AND
             (CC.CDFILIAL     = V_CDFILIAL)                      AND
             (CC.NRCARDAPIO   = CA.NRCARDAPIO)                   AND
             (CM.CDFILIAL     = V_CDFILIAL)                      AND
             (CM.CDSERVFILI   = V_CDSERVFILI)                    AND
             (CM.DTREFECNFMES = CA.DTMESCARD)                    AND
             (CM.NRSEQCNFMES  = CC.NRSEQPRATCAR)                 AND
             (RF.CDFILIAL     = V_CDFILIAL)                      AND
             (RF.CDFILAUXPRAT = CC.CDFILAUXPRAT)                 AND
             (RF.CDPRATO      = CC.CDPRATO)                      AND
             (PR.CDPRODUTO    = RF.CDPRODUTO)                    AND
             NOT EXISTS (SELECT
                            CDPRATO
                         FROM
                            RECESERV
                         WHERE
                            (CDFILAUXPRAT = CC.CDFILAUXPRAT) AND
                            (CDPRATO      = CC.CDPRATO)      AND
                            (CDFILIAL     = V_CDFILIAL)      AND
                            (CDSERVFILI   = V_CDSERVFILI)
                         )
          UNION ALL
          SELECT
             CA.CDFILIAL,
             CA.CDSERVFILI,
             CA.DTCARDAPIO,
             CA.DTMESCARD,
             CC.NRSEQPRATCAR,
             CC.CDTIPOPRAT,
             CC.CDFILAUXPRAT,
             CC.CDPRATO,
             CM.IDOPCCNFMES,
             RP.CDPRODUTO,
             RP.QTUNIDESTPR AS QTPRODUTO
          FROM
             CARDADIA CA,
             COMPCARD CC,
             CNFCAMES CM,
             RECEPADR RP,
             PRODUTO PR
          WHERE
             (CA.CDFILIAL     = V_CDFILIAL)             AND
             (CA.CDSERVFILI   = V_CDSERVFILI)           AND
             (CA.DTCARDAPIO BETWEEN P_DTINICIAL AND P_DTFINAL)   AND
             (CC.CDFILIAL     = V_CDFILIAL)                      AND
             (CC.NRCARDAPIO   = CA.NRCARDAPIO)                   AND
             (CM.CDFILIAL     = V_CDFILIAL)                      AND
             (CM.CDSERVFILI   = V_CDSERVFILI)                    AND
             (CM.DTREFECNFMES = CA.DTMESCARD)                    AND
             (CM.NRSEQCNFMES  = CC.NRSEQPRATCAR)                 AND
             (RP.CDFILAUXPRAT = 'P')                             AND
             (RP.CDPRATO      = CC.CDPRATO)                      AND
             (PR.CDPRODUTO    = RP.CDPRODUTO)                    AND
             NOT EXISTS (SELECT
                            CDPRATO
                         FROM
                            RECEFILI
                         WHERE
                            (CDFILAUXPRAT = CC.CDFILAUXPRAT) AND
                            (CDPRATO      = CC.CDPRATO)      AND
                            (CDFILIAL     = V_CDFILIAL)
                         )
             AND
             NOT EXISTS (SELECT
                            CDPRATO
                         FROM
                            RECESERV
                         WHERE
                            (CDFILAUXPRAT = CC.CDFILAUXPRAT) AND
                            (CDPRATO      = CC.CDPRATO)      AND
                            (CDFILIAL     = V_CDFILIAL)     AND
                            (CDSERVFILI   = V_CDSERVFILI)
                         )
          ) PC
      WHERE
         (LP.CDFILIAL   = V_CDFILIAL)   AND
         (LP.CDSERVFILI = V_CDSERVFILI) AND
         (INSTR(PC.CDPRODUTO, LP.CDPRODUTO) = 1) AND
         ((PC.QTPRODUTO < LP.QTMINLIMSERV) OR
          (PC.QTPRODUTO > LP.QTMAXLIMSERV))      AND
         (PR.CDPRODUTO  = LP.CDPRODUTO);     
   RECORD_LIMPERSER C_LIMPERSER%ROWTYPE;
   /*Restrio de Produtos */
   CURSOR C_RESTPROD(V_CDFILIAL VARCHAR2,
                     V_CDSERVFILI VARCHAR2,
                     P_DTINICIAL DATE,
                     P_DTFINAL DATE)
   IS
      SELECT COUNT(*) AS RESTRICAO
      FROM
         RESTPROD RP,
         PRODUTO PR,
         (SELECT
             CA.CDFILIAL,
             CA.CDSERVFILI,
             CA.DTCARDAPIO,
             CA.DTMESCARD,
             CC.NRSEQPRATCAR,
             CC.CDTIPOPRAT,
             CC.CDFILAUXPRAT,
             CC.CDPRATO,
             CM.IDOPCCNFMES,
             RS.CDPRODUTO,
             RS.QTUNIDESTSE AS QTPRODUTO,
             PR.CDARVPROD
          FROM
             CARDADIA CA,
             COMPCARD CC,
             CNFCAMES CM,
             RECESERV RS,
             PRODUTO PR
          WHERE
             (CA.CDFILIAL     = V_CDFILIAL)             AND
             (CA.CDSERVFILI   = V_CDSERVFILI)           AND
             (CA.DTCARDAPIO BETWEEN P_DTINICIAL AND P_DTFINAL)   AND
             (CC.CDFILIAL     = V_CDFILIAL)                      AND
             (CC.NRCARDAPIO   = CA.NRCARDAPIO)                   AND
             (CM.CDFILIAL     = V_CDFILIAL)                      AND
             (CM.CDSERVFILI   = V_CDSERVFILI)                    AND
             (CM.DTREFECNFMES = CA.DTMESCARD)                    AND
             (CM.NRSEQCNFMES  = CC.NRSEQPRATCAR)                 AND
             (RS.CDFILIAL     = V_CDFILIAL)                      AND
             (RS.CDSERVFILI   = V_CDSERVFILI)                    AND
             (RS.CDFILAUXPRAT = CC.CDFILAUXPRAT)                 AND
             (RS.CDPRATO      = CC.CDPRATO)                      AND
             (PR.CDPRODUTO    = RS.CDPRODUTO)
          UNION ALL
          SELECT
             CA.CDFILIAL,
             CA.CDSERVFILI,
             CA.DTCARDAPIO,
             CA.DTMESCARD,
             CC.NRSEQPRATCAR,
             CC.CDTIPOPRAT,
             CC.CDFILAUXPRAT,
             CC.CDPRATO,
             CM.IDOPCCNFMES,
             RF.CDPRODUTO,
             RF.QTUNIDESTLO AS QTPRODUTO,
             PR.CDARVPROD
          FROM
             CARDADIA CA,
             COMPCARD CC,
             CNFCAMES CM,
             RECEFILI RF,
             PRODUTO PR
          WHERE
             (CA.CDFILIAL     = V_CDFILIAL)             AND
             (CA.CDSERVFILI   = V_CDSERVFILI)           AND
             (CA.DTCARDAPIO BETWEEN P_DTINICIAL AND P_DTFINAL)   AND
             (CC.CDFILIAL     = V_CDFILIAL)                      AND
             (CC.NRCARDAPIO   = CA.NRCARDAPIO)                   AND
             (CM.CDFILIAL     = V_CDFILIAL)                      AND
             (CM.CDSERVFILI   = V_CDSERVFILI)                    AND
             (CM.DTREFECNFMES = CA.DTMESCARD)                    AND
             (CM.NRSEQCNFMES  = CC.NRSEQPRATCAR)                 AND
             (RF.CDFILIAL     = V_CDFILIAL)                      AND
             (RF.CDFILAUXPRAT = CC.CDFILAUXPRAT)                 AND
             (RF.CDPRATO      = CC.CDPRATO)                      AND
             (PR.CDPRODUTO    = RF.CDPRODUTO)                    AND
             NOT EXISTS (SELECT
                            CDPRATO
                         FROM
                            RECESERV
                         WHERE
                            (CDFILAUXPRAT = CC.CDFILAUXPRAT) AND
                            (CDPRATO      = CC.CDPRATO)      AND
                            (CDFILIAL     = V_CDFILIAL)      AND
                            (CDSERVFILI   = V_CDSERVFILI)
                         )
          UNION ALL
          SELECT
             CA.CDFILIAL,
             CA.CDSERVFILI,
             CA.DTCARDAPIO,
             CA.DTMESCARD,
             CC.NRSEQPRATCAR,
             CC.CDTIPOPRAT,
             CC.CDFILAUXPRAT,
             CC.CDPRATO,
             CM.IDOPCCNFMES,
             RP.CDPRODUTO,
             RP.QTUNIDESTPR AS QTPRODUTO,
             PR.CDARVPROD
          FROM
             CARDADIA CA,
             COMPCARD CC,
             CNFCAMES CM,
             RECEPADR RP,
             PRODUTO PR
          WHERE
             (CA.CDFILIAL     = V_CDFILIAL)             AND
             (CA.CDSERVFILI   = V_CDSERVFILI)           AND
             (CA.DTCARDAPIO BETWEEN P_DTINICIAL AND P_DTFINAL)   AND
             (CC.CDFILIAL     = V_CDFILIAL)                      AND
             (CC.NRCARDAPIO   = CA.NRCARDAPIO)                   AND
             (CM.CDFILIAL     = V_CDFILIAL)                      AND
             (CM.CDSERVFILI   = V_CDSERVFILI)                    AND
             (CM.DTREFECNFMES = CA.DTMESCARD)                    AND
             (CM.NRSEQCNFMES  = CC.NRSEQPRATCAR)                 AND
             (RP.CDFILAUXPRAT = 'P')                             AND
             (RP.CDPRATO      = CC.CDPRATO)                      AND
             (PR.CDPRODUTO    = RP.CDPRODUTO)                    AND
             NOT EXISTS (SELECT
                            CDPRATO
                         FROM
                            RECEFILI
                         WHERE
                            (CDFILAUXPRAT = CC.CDFILAUXPRAT) AND
                            (CDPRATO      = CC.CDPRATO)      AND
                            (CDFILIAL     = V_CDFILIAL)
                         )
             AND
             NOT EXISTS (SELECT
                            CDPRATO
                         FROM
                            RECESERV
                         WHERE
                            (CDFILAUXPRAT = CC.CDFILAUXPRAT) AND
                            (CDPRATO      = CC.CDPRATO)      AND
                            (CDFILIAL     = V_CDFILIAL)     AND
                            (CDSERVFILI   = V_CDSERVFILI)
                         )
          ) PC
      WHERE
         (RP.CDFILIAL   = V_CDFILIAL)   AND
         (RP.CDSERVFILI = V_CDSERVFILI) AND
         (INSTR(PC.CDARVPROD, PR.CDARVPROD) = 1) AND
         (PR.CDPRODUTO  = RP.CDPRODUTO);
   RECORD_RESTPROD C_RESTPROD%ROWTYPE;
BEGIN
   V_RESTRICAO := 0;
   V_IDRESTRAPROVCARD := 'N';
   FOR CUR_FILIAL IN
      (SELECT CDFILIAL, CDSERVFILI
         FROM LISTA_SERVICO
        WHERE NRLISTA = P_NRLISTA
       UNION
       SELECT CDFILIAL, CDSERVFILI
         FROM SERVICO
        WHERE CDFILIAL   = P_CDFILIAL
          AND CDSERVFILI = P_CDSERVFILI)
   LOOP
      BEGIN
         SELECT NVL(IDRESTRAPROVCARD,'N')
           INTO V_IDRESTRAPROVCARD
           FROM PARAMPLANEJA
          WHERE CDFILIAL = CUR_FILIAL.CDFILIAL;
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            V_IDRESTRAPROVCARD := 'N';
      END;
      IF (V_IDRESTRAPROVCARD = 'S') OR (P_VERRESTR = 'S') THEN
         /*Frequncia de Pratos no Ms*/
         IF (V_RESTRICAO = 0) THEN
            OPEN C_FREQPRATMES(CUR_FILIAL.CDFILIAL, CUR_FILIAL.CDSERVFILI, P_DTINICIAL, P_DTFINAL);
            LOOP
                FETCH C_FREQPRATMES INTO RECORD_FREQPRATMES;
                EXIT WHEN C_FREQPRATMES%NOTFOUND;
                IF RECORD_FREQPRATMES.RESTRICAO > 0 THEN
                   V_RESTRICAO := RECORD_FREQPRATMES.RESTRICAO;
                   V_OUT_RECORD.CDFILIAL    := CUR_FILIAL.CDFILIAL;
                   V_OUT_RECORD.CDSERVFILI  := CUR_FILIAL.CDSERVFILI;
                   PIPE ROW (V_OUT_RECORD);
                ELSE
                   V_RESTRICAO := 0;
                END IF;
            END LOOP;
            CLOSE C_FREQPRATMES;
            IF V_RESTRICAO = 0 THEN
               OPEN C_FREQPRATMESMIN(CUR_FILIAL.CDFILIAL, CUR_FILIAL.CDSERVFILI, P_DTINICIAL, P_DTFINAL);
               LOOP
                   FETCH C_FREQPRATMESMIN INTO RECORD_FREQPRATMESMIN;
                   EXIT WHEN C_FREQPRATMESMIN%NOTFOUND;
                   IF RECORD_FREQPRATMESMIN.RESTRICAO > 0 THEN
                      V_RESTRICAO := RECORD_FREQPRATMESMIN.RESTRICAO;
                      V_OUT_RECORD.CDFILIAL    := CUR_FILIAL.CDFILIAL;
                      V_OUT_RECORD.CDSERVFILI  := CUR_FILIAL.CDSERVFILI;
                      PIPE ROW (V_OUT_RECORD);
                   ELSE
                      V_RESTRICAO := 0;
                   END IF;
               END LOOP;
               CLOSE C_FREQPRATMESMIN;
            END IF;
         END IF;
         /*Frequncia de Opes no Ms*/
         IF (V_RESTRICAO = 0) THEN
            OPEN C_FREQOPCASEM(CUR_FILIAL.CDFILIAL, CUR_FILIAL.CDSERVFILI, P_DTINICIAL, P_DTFINAL);
            LOOP
                FETCH C_FREQOPCASEM INTO RECORD_FREQOPCASEM;
                EXIT WHEN C_FREQOPCASEM%NOTFOUND;
                IF RECORD_FREQOPCASEM.RESTRICAO > 0 THEN
                   V_RESTRICAO := RECORD_FREQOPCASEM.RESTRICAO;
                   V_OUT_RECORD.CDFILIAL    := CUR_FILIAL.CDFILIAL;
                   V_OUT_RECORD.CDSERVFILI  := CUR_FILIAL.CDSERVFILI;
                   PIPE ROW (V_OUT_RECORD);
                ELSE
                   V_RESTRICAO := 0;
                END IF;
            END LOOP;
            CLOSE C_FREQOPCASEM;
            IF V_RESTRICAO = 0 THEN
               OPEN C_FREQOPCASEMMIN(CUR_FILIAL.CDFILIAL, CUR_FILIAL.CDSERVFILI, P_DTINICIAL, P_DTFINAL);
               LOOP
                   FETCH C_FREQOPCASEMMIN INTO RECORD_FREQOPCASEMMIN;
                   EXIT WHEN C_FREQOPCASEMMIN%NOTFOUND;
                   IF RECORD_FREQOPCASEMMIN.RESTRICAO > 0 THEN
                      V_RESTRICAO := RECORD_FREQOPCASEMMIN.RESTRICAO;
                      V_OUT_RECORD.CDFILIAL    := CUR_FILIAL.CDFILIAL;
                      V_OUT_RECORD.CDSERVFILI  := CUR_FILIAL.CDSERVFILI;
                      PIPE ROW (V_OUT_RECORD);
                   ELSE
                      V_RESTRICAO := 0;
                   END IF;
               END LOOP;
               CLOSE C_FREQOPCASEMMIN;
            END IF;
         END IF;
         /*Restrio de Pratos no Ms*/
         IF (V_RESTRICAO = 0) THEN
            OPEN C_RESTPRATMES(CUR_FILIAL.CDFILIAL, CUR_FILIAL.CDSERVFILI, P_DTINICIAL, P_DTFINAL);
            LOOP
                FETCH C_RESTPRATMES INTO RECORD_RESTPRATMES;
                EXIT WHEN C_RESTPRATMES%NOTFOUND;
                IF RECORD_RESTPRATMES.RESTRICAO > 0 THEN
                   V_RESTRICAO := RECORD_RESTPRATMES.RESTRICAO;
                   V_OUT_RECORD.CDFILIAL    := CUR_FILIAL.CDFILIAL;
                   V_OUT_RECORD.CDSERVFILI  := CUR_FILIAL.CDSERVFILI;
                   PIPE ROW (V_OUT_RECORD);
                ELSE
                   V_RESTRICAO := 0;
                END IF;
            END LOOP;
            CLOSE C_RESTPRATMES;
         END IF;
         /*Restrio de Opces no Ms*/
         IF (V_RESTRICAO = 0) THEN
            OPEN C_RESTOPCA(CUR_FILIAL.CDFILIAL, CUR_FILIAL.CDSERVFILI, P_DTINICIAL, P_DTFINAL);
            LOOP
                FETCH C_RESTOPCA INTO RECORD_RESTOPCA;
                EXIT WHEN C_RESTOPCA%NOTFOUND;
                IF RECORD_RESTOPCA.RESTRICAO > 0 THEN
                   V_RESTRICAO := RECORD_RESTOPCA.RESTRICAO;
                   V_OUT_RECORD.CDFILIAL    := CUR_FILIAL.CDFILIAL;
                   V_OUT_RECORD.CDSERVFILI  := CUR_FILIAL.CDSERVFILI;
                   PIPE ROW (V_OUT_RECORD);
                ELSE
                   V_RESTRICAO := 0;
                END IF;
            END LOOP;
            CLOSE C_RESTOPCA;
         END IF;
         /*Utilizao de Pratos na Semana*/
         IF (V_RESTRICAO = 0) THEN
            OPEN C_UTILPRAT(CUR_FILIAL.CDFILIAL, CUR_FILIAL.CDSERVFILI, P_DTINICIAL, P_DTFINAL);
            LOOP
                FETCH C_UTILPRAT INTO RECORD_UTILPRAT;
                EXIT WHEN C_UTILPRAT%NOTFOUND;
                IF RECORD_UTILPRAT.RESTRICAO > 0 THEN
                   V_RESTRICAO := RECORD_UTILPRAT.RESTRICAO;
                   V_OUT_RECORD.CDFILIAL    := CUR_FILIAL.CDFILIAL;
                   V_OUT_RECORD.CDSERVFILI  := CUR_FILIAL.CDSERVFILI;
                   PIPE ROW (V_OUT_RECORD);
                ELSE
                   V_RESTRICAO := 0;
                END IF;
            END LOOP;
            CLOSE C_UTILPRAT;
         END IF;
         /*Limite de Nutrientes por Servio*/
         IF (V_RESTRICAO = 0) THEN
            OPEN C_LIMNUTRI(CUR_FILIAL.CDFILIAL, CUR_FILIAL.CDSERVFILI, P_DTINICIAL, P_DTFINAL);
            LOOP
                FETCH C_LIMNUTRI INTO RECORD_LIMNUTRI;
                EXIT WHEN C_LIMNUTRI%NOTFOUND;
                IF RECORD_LIMNUTRI.RESTRICAO > 0 THEN
                   V_RESTRICAO := RECORD_LIMNUTRI.RESTRICAO;
                   V_OUT_RECORD.CDFILIAL    := CUR_FILIAL.CDFILIAL;
                   V_OUT_RECORD.CDSERVFILI  := CUR_FILIAL.CDSERVFILI;
                   PIPE ROW (V_OUT_RECORD);
                ELSE
                   V_RESTRICAO := 0;
                END IF;
            END LOOP;
            CLOSE C_LIMNUTRI;
         END IF;
         /*Limite de Per Capita por Prato*/
         IF (V_RESTRICAO = 0)THEN
            OPEN C_LIMPERPRAT(CUR_FILIAL.CDFILIAL, CUR_FILIAL.CDSERVFILI, P_DTINICIAL, P_DTFINAL);
            LOOP
                FETCH C_LIMPERPRAT INTO RECORD_LIMPERPRAT;
                EXIT WHEN C_LIMPERPRAT%NOTFOUND;
                IF RECORD_LIMPERPRAT.RESTRICAO > 0 THEN
                   V_RESTRICAO := RECORD_LIMPERPRAT.RESTRICAO;
                   V_OUT_RECORD.CDFILIAL    := CUR_FILIAL.CDFILIAL;
                   V_OUT_RECORD.CDSERVFILI  := CUR_FILIAL.CDSERVFILI;
                   PIPE ROW (V_OUT_RECORD);
                ELSE
                   V_RESTRICAO := 0;
                END IF;
            END LOOP;
            CLOSE C_LIMPERPRAT;
         END IF;
         /*Limite de Per Capita por Servio*/
         IF (V_RESTRICAO = 0) THEN
            OPEN C_LIMPERSER(CUR_FILIAL.CDFILIAL, CUR_FILIAL.CDSERVFILI, P_DTINICIAL, P_DTFINAL);
            LOOP
                FETCH C_LIMPERSER INTO RECORD_LIMPERSER;
                EXIT WHEN C_LIMPERSER%NOTFOUND;
                IF RECORD_LIMPERSER.RESTRICAO > 0 THEN
                   V_RESTRICAO := RECORD_LIMPERSER.RESTRICAO;
                   V_OUT_RECORD.CDFILIAL    := CUR_FILIAL.CDFILIAL;
                   V_OUT_RECORD.CDSERVFILI  := CUR_FILIAL.CDSERVFILI;
                   PIPE ROW (V_OUT_RECORD);
                ELSE
                   V_RESTRICAO := 0;
                END IF;
            END LOOP;
            CLOSE C_LIMPERSER;
         END IF;
         /*Restrio de Produtos */
         IF (V_RESTRICAO = 0 ) THEN
            OPEN C_RESTPROD(CUR_FILIAL.CDFILIAL, CUR_FILIAL.CDSERVFILI, P_DTINICIAL, P_DTFINAL);
            LOOP
                FETCH C_RESTPROD INTO RECORD_RESTPROD;
                EXIT WHEN C_RESTPROD%NOTFOUND;
                IF RECORD_RESTPROD.RESTRICAO > 0 THEN
                   V_RESTRICAO := RECORD_RESTPROD.RESTRICAO;
                   V_OUT_RECORD.CDFILIAL    := CUR_FILIAL.CDFILIAL;
                   V_OUT_RECORD.CDSERVFILI  := CUR_FILIAL.CDSERVFILI;
                   PIPE ROW (V_OUT_RECORD);
                ELSE
                   V_RESTRICAO := 0;
                END IF;
            END LOOP;
            CLOSE C_RESTPROD;
         END IF;
         V_RESTRICAO := 0;
      END IF;
   END LOOP;
   RETURN;
END;
/

-- VERSAO --
BEGIN ATUVEROBJ('RESTR_CONTRATUAIS_CARD','6.05.000'); END;
/


